#!/bin/bash

# config.sh:

# The next few VARIABLES are to be edited as required:

# Package name. (In multibuild, it's the base package). Used to ref spec file.
PKG=qemu

# Here is the git repo which tracks a separate upstream git based project
# We take this approach so we can have our own tags and branches, and store
# the patches in git for others to access outside of the bundle.
PACKAGE_MAIN_GIT_REPO=https://github.com/openSUSE/qemu.git

# This is the upstream for the PACKAGE_MAIN_GIT_REPO
UPSTREAM_GIT_REPO=https://gitlab.com/qemu-project/qemu.git

# The following specifies the upstream tag or commit upon which our patchqueue
# gets rebased. The special value LATEST may be used to "automatically" track
# the upstream development tree in the master branch
GIT_UPSTREAM_COMMIT_ISH=v3.1.1.1
# WARNING: If transitioning from using LATEST to not, MANUALLY re-set the
# tarball present. If transitioning TO LATEST, make sure that
# NEXT_RELEASE_IS_MAJOR is set correctly
# This is used to choose the version number when LATEST processing is active
NEXT_RELEASE_IS_MAJOR=0

# Unfortunately, SeaBIOS doesn't always follow an "always increasing" version
# model, so there may be times we should overide the automated version setting.
# We can do so by specifing the value here:
#SEABIOS_VERSION=1.12.1+

# In following, use 1 or 0 as needed (representing true or false respectively)
NUMBERED_PATCHES=1

PATCH_RANGE=1000

# For compatibility with old packages, we include this option
OVERRIDE_FIVE_DIGIT_NUMBERING=1

# This array tracks all git submodule paths within the superproject (1st entry)
PATCH_PATH_MAP=(
    ""
    "roms/seabios/"
    "roms/ipxe/"
    "roms/sgabios/"
    "roms/skiboot/"
    "roms/SLOF/"
    "roms/openbios/"
    "ui/keycodemapdb/"
    "roms/u-boot/"
    "roms/openhackware/"
    "dtc/"
    "capstone/"
    "roms/qemu-palcode/"
    "roms/seabios-hppa/"
    "roms/u-boot-sam460ex/"
    "roms/QemuMacDrivers/"
    "tests/fp/berkeley-softfloat-3/"
    "tests/fp/berkeley-testfloat-3/"
)

# (order and count must correspond to PATCH_PATH_MAP)
LOCAL_REPO_MAP=(
    ~/git/qemu-opensuse
    ~/git/qemu-seabios
    ~/git/qemu-ipxe
    ~/git/qemu-sgabios
    ~/git/qemu-skiboot
    ~/git/qemu-SLOF
    ~/git/qemu-openbios
    ~/git/qemu-keycodemapdb
    ~/git/qemu-u-boot
    ~/git/qemu-openhackware
    ~/git/qemu-dtc
    ~/git/qemu-capstone
    ~/git/qemu-qemu-palcode
    ~/git/qemu-seabios-hppa
    ~/git/qemu-u-boot-sam460ex
    ~/git/qemu-QemuMacDrivers
    ~/git/qemu-tests-berkeley-softfloat-3
    ~/git/qemu-tests-berkeley-testfloat-3
)
